<?php
require_once dirname(__FILE__) . '/Element.php';

/**
	The document model class about `class`.

	Examples
	--------

	When:

		/**
			description about class.
		*\/
		final class hello {
		}

		$helloclass = new docudown_class('hello');

	or:

		$helloclass = new docudown_class(new ReflectionClass('hello'));

	it runs as:

		>>> $HelloClass->name
		==> 'Hello'
		>>> $HelloClass->title
		==> 'final class Hello'
		>>> $HelloClass->keys
		==> array('Hello')
		>>> $HelloClass->plainText
		==> 'Description about class.'
*/
class Docudown_Class extends Docudown_Element {
	public $name;

	function __construct($class) {
		if($class instanceof ReflectionClass) {
			parent::__construct($class);
			$this->name = $class->getName();
		}
		else {
			$this->name = strval($class);
			parent::__construct(new ReflectionClass($this->name));
		}
	}

	protected function getTitle() {
		$modifiers = array();

		if($this->reflection->isFinal())
			$modifiers[] = 'final';

		if($this->reflection->isAbstract())
			$modifiers[] = 'abstract';

		$modifiers[] = "class $this->name";
		return join(' ', $modifiers);
	}

	function matches($identifier) {
		return strtolower($identifier) == strtolower($this->name);
	}
}
