<?php

/**
	The abstract class about elements that can be documented.
*/
abstract class Docudown_Element {
	public $reflection;

	function __construct(Reflector $reflection) {
		$this->reflection = $reflection;
	}

	abstract protected function getTitle();

	final protected function getPlainText() {
		if(false === $comment = $this->reflection->getDocComment())
			return null;

		preg_match('{/\*\*(.*?)\*/}s', $comment, $matches);
		$lines = split("[\n\r]", $matches[1]);

		foreach($lines as $line) if(trim($line)) {
			preg_match('{^\s*}', $line, $matches);
			$pad = strlen($matches[0]);
			$minPad = isset($minPad) ? min($pad, $minPad) : $pad;
		}

		if(!isset($minPad))
			$minPad = 0;

		foreach($lines as $i => &$line)
			$line = (string) substr($line, $minPad);

		if(trim($lines[0]) == '')
			array_shift($lines);
		if(trim(end($lines)) == '')
			array_pop($lines);

		return str_replace('\/', '/', join("\n", $lines));
	}

	final function __get($name) {
		if($this->__isset($name))
			return $this->{"get$name"}();
	}

	final function __isset($name) {
		return method_exists($this, "get$name");
	}
}

